<?php
/**
 * artex functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package artex
 */

if ( ! function_exists( 'artex_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function artex_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on artex, use a find and replace
	 * to change 'artex' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'artex', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

		// Add editor styling
	add_editor_style( 'editor-style.css' );
	
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'artex_big', 750, 350, array('center','top') ); //big Post Featured
	add_image_size( 'artex_smallfeatured', 280, 250, array('center','top') ); //featured image
	add_image_size( 'artex_small', 120, 120, true ); //small
	

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'artex' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'artex_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'artex_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function artex_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'artex_content_width', 640 );
}
add_action( 'after_setup_theme', 'artex_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function artex_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'artex' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	//Register footer 1
	register_sidebar( array(
		'name'          => esc_html__( 'Footer-1', 'artex' ),
		'id'            => 'footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	//Register footer 2
	register_sidebar( array(
		'name'          => esc_html__( 'Footer-2', 'artex' ),
		'id'            => 'footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	//Register footer 3
	register_sidebar( array(
		'name'          => esc_html__( 'Footer-3', 'artex' ),
		'id'            => 'footer-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	//Register footer 4
	register_sidebar( array(
		'name'          => esc_html__( 'Footer-4', 'artex' ),
		'id'            => 'footer-4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'artex_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function artex_scripts() {
	wp_enqueue_style( 'artex-style', get_stylesheet_uri() );

	wp_enqueue_script( 'artex-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	
	wp_enqueue_style( 'artex-bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	
	 wp_enqueue_style('fontawesome', get_template_directory_uri().'/css/font-awesome.css', 'all');

	wp_enqueue_script( 'artex-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'artex_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/*-----------------------------------------------------------------------------------*/
/*  Cartex-entry-meta
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'artex_entry_meta' ) ) :
	/**
	 * Output entry-meta tag
	 *
	 * @since artex 1.0
	 */
	function artex_entry_meta() { ?>
		<div class="post-meta">
				<ul>
				<li><button type="button" class="btn btn-danger btn-xs"> <?php the_category(); ?></button><li>
				<li><i class="fa fa-user"></i> <?php the_author(); ?><li>
				<li><i class="fa fa-calendar"></i> <?php the_time( get_option( 'date_format' ) ); ?><li>
				<li><a class="artex-meta-comment" href="<?php comments_link(); ?>"><i class="fa fa-comments"></i> <?php comments_number(__( 'No Comment', 'artex'), __('1 Comment', 'artex'), __('% Comments', 'artex')); ?></a><li>
				
			</ul>
			</div><!-- end .artex-meta -->
		<?php
	}
endif;

/*-----------------------------------------------------------------------------------*/
/*  Custom Excerpts. words counted on your posts
/*-----------------------------------------------------------------------------------*/
function artex_new_excerpt_more ($more){
	return '...';
}
add_filter('excerpt_more','artex_new_excerpt_more');

function artex_custom_excerpt_length ($lenth){
	return 80; // Excerpts
}
add_filter ('excerpt_length', 'artex_custom_excerpt_length', 999);


/*-----------------------------------------------------------------------------------*/
/*  Single Post Settings
/*-----------------------------------------------------------------------------------*/
		
//Display Post Next/Prev buttons if enabled.
if ( ! function_exists( 'artex_next_prev_post' ) ) {
function artex_next_prev_post() { ?>
	<div class="next_prev_post">
		<?php 
			previous_post_link( '<div class="nav-previous"> %link</div>', '<i class="fa fa-chevron-left"></i>'. __('Previous Post','artex'));
			next_post_link( '<div class="nav-n ext">%link</div>', __('Next Post','artex'). '<i class="fa fa-chevron-right"></i>' );
		?>
	</div><!-- .next_prev_post -->
<?php }                 
}

/*-----------------------------------------------------------------------------------*/
/*  Pagination (for WP 4.0 and earlier versions)
/*-----------------------------------------------------------------------------------*/
if (!function_exists('artex_pagination')) {
	function artex_pagination($pages = '', $range = 3) { 
		$showitems = ($range * 3)+1;
		global $paged; if(empty($paged)) $paged = 1;
		if($pages == '') {
			global $wp_query; $pages = $wp_query->max_num_pages; 
			if(!$pages){ $pages = 1; } 
		}
	if(1 != $pages) { 
		echo "<div class='pagination'><ul>";
			if($paged > 2 && $paged > $range+1 && $showitems < $pages) 
			echo "<li><a rel='nofollow' href='".get_pagenum_link(1)."'><i class='fa fa-chevron-left'></i> ".__('First','artex')."</a></li>";
		if($paged > 1 && $showitems < $pages) 
			echo "<li><a rel='nofollow' href='".get_pagenum_link($paged - 1)."' class='inactive'>&lsaquo; ".__('Previous','artex')."</a></li>";
			for ($i=1; $i <= $pages; $i++){ 
				if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )) { 
					echo ($paged == $i)? "<li class='current'><span class='currenttext'>".$i."</span></li>":"<li><a rel='nofollow' href='".get_pagenum_link($i)."' class='inactive'>".$i."</a></li>";
				} 
			} 
			if ($paged < $pages && $showitems < $pages) 
			echo "<li><a rel='nofollow' href='".get_pagenum_link($paged + 1)."' class='inactive'>".__('Next','artex')." &rsaquo;</a></li>";
			if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) 
			echo "<li><a rel='nofollow' class='inactive' href='".get_pagenum_link($pages)."'>".__('Last','artex')." &raquo;</a></li>";
			echo "</ul></div>"; 
		}
	}
}